package com.gic.cloud.service.impl;

import com.gic.cloud.dao.mapper.TabIndexMapper;
import com.gic.cloud.dto.IndexDTO;
import com.gic.cloud.entity.TabIndex;
import com.gic.cloud.qo.IndexQO;
import com.gic.cloud.service.IndexGroupService;
import com.gic.cloud.service.IndexModuleRelService;
import com.gic.cloud.service.IndexService;
import com.gic.commons.util.EntityUtil;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.Collections;
import java.util.Date;
import java.util.List;

/**
 * @author zhiwj
 * @Description:
 * @date 2020-07-08 10:20
 */
@Service
public class IndexServiceImpl implements IndexService {

    @Autowired
    private TabIndexMapper tabIndexMapper;
    @Autowired
    private IndexModuleRelService indexModuleRelService;
    @Autowired
    private IndexGroupService indexGroupService;

    @Override
    public boolean isNameRepeat(String name, Integer indexId) {
        TabIndex tabIndex = new TabIndex();
        tabIndex.setName(name);
        tabIndex.setIndexId(indexId);
        return tabIndexMapper.getBySelective(tabIndex) != null;
    }

    @Override
    public boolean isCodeRepeat(String code, Integer indexId) {
        TabIndex tabIndex = new TabIndex();
        tabIndex.setCode(code);
        tabIndex.setIndexId(indexId);
        return tabIndexMapper.getBySelective(tabIndex) != null;
    }

    @Override
    public Integer save(IndexDTO indexDTO) {
        TabIndex tabIndex = EntityUtil.changeEntityByJSON(TabIndex.class, indexDTO);
        tabIndex.setStatus(1);
        tabIndex.setCreateTime(new Date());
        tabIndex.setUpdateTime(new Date());
        tabIndexMapper.insertSelective(tabIndex);
        return tabIndex.getIndexId();
    }

    @Override
    public void update(IndexDTO indexDTO) {
        TabIndex tabIndex = EntityUtil.changeEntityByJSON(TabIndex.class, indexDTO);
        tabIndexMapper.updateByPrimaryKeySelective(tabIndex);
    }

    @Override
    public TabIndex getByIndexId(Integer indexId) {
        return tabIndexMapper.selectByPrimaryKey(indexId);
    }

    @Override
    public Page<TabIndex> listIndex(IndexQO indexQO) {
        PageHelper.startPage(indexQO.getCurrentPage(), indexQO.getPageSize());
        if (StringUtils.isNotBlank(indexQO.getModuleId())) {
            List<Integer> indexIdList = indexModuleRelService.listBusinessIdByModuleIds(Arrays.asList(indexQO.getModuleId().split(",")));
            indexQO.setIndexIdList(indexIdList);
        }
        if (indexQO.getIndexGroupId() != null) {
            List<Integer> indexGroupIdList = indexGroupService.listChildIndexGroup(indexQO.getIndexGroupId());
            indexQO.setIndexGroupIdList(indexGroupIdList);
        }
        return tabIndexMapper.listIndex(indexQO);
    }

    @Override
    public List<TabIndex> listAllIndex(IndexQO indexQO) {
        return tabIndexMapper.listIndex(indexQO);
    }

    @Override
    public void deleteById(Integer indexId) {
        TabIndex index = new TabIndex();
        index.setIndexId(indexId);
        index.setStatus(0);
        tabIndexMapper.updateByPrimaryKeySelective(index);
    }

    @Override
    public TabIndex getByIndexCode(String moduleId, String indexCode) {
        IndexQO indexQO = new IndexQO();
        PageHelper.startPage(1, 1);
        List<Integer> indexIdList = indexModuleRelService.listBusinessIdByModuleIds(Collections.singletonList(moduleId));
        if (CollectionUtils.isEmpty(indexIdList)) {
            return null;
        }
        indexQO.setIndexIdList(indexIdList);
        indexQO.setCode(indexCode);
        Page<TabIndex> page = tabIndexMapper.listIndex(indexQO);
        if (CollectionUtils.isEmpty(page)) {
            return null;
        } else {
            return page.get(0);
        }
    }
}
