package com.gic.cloud.web.controller;

import com.alibaba.fastjson.JSON;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.cloud.dto.FunctionDTO;
import com.gic.cloud.dto.FunctionModuleDTO;
import com.gic.cloud.service.FunctionApiService;
import com.gic.cloud.service.FunctionModuleApiService;
import com.gic.cloud.service.IndexApiService;
import com.gic.cloud.web.auth.DataAuthUtils;
import com.gic.cloud.web.qo.DateTypeQo;
import com.gic.cloud.web.utils.DataFormatUtils;
import com.gic.cloud.web.vo.FunctionModuleVo;
import com.gic.cloud.web.vo.LevelNameVo;
import com.gic.cloud.web.vo.LevelVo;
import com.gic.cloud.web.vo.MbrVo;
import com.gic.cloud.web.vo.index.IndexConsume;
import com.gic.cloud.web.vo.index.IndexSalesVo;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.data.api.dto.*;
import com.gic.data.api.service.IndexSalesApiService;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

@RestController
public class IndexController {
    private Logger log = LogManager.getLogger(IndexController.class);
    @Autowired
    private IndexSalesApiService indexSalesApiService;
    @Autowired
    private StoreSearchUtils storeSearchUtils;
    @Autowired
    private DataAuthUtils dataAuthUtils;
    @Autowired
    private FunctionApiService functionApiService;

    @RequestMapping("index-mbr")
    public RestResponse indexMbr(Integer enterpriseId, Integer userId){
        List<MbrVo> mbrArea = this.dataAuthUtils.getMbrArea(userId, enterpriseId);
        return RestResponse.success(mbrArea);
    }

    @RequestMapping("index-sales")
    public RestResponse indexSales(Integer userId, Integer enterpriseId, String searchJSON,
                                   DateTypeQo dateTypeQo, String mbrAreaId, Integer dataType){
        List<Integer> list = this.storeSearchUtils.storeSearch(userId, enterpriseId, searchJSON);
        List<String> onLine = this.storeSearchUtils.onLineStoreSearch(userId, enterpriseId, searchJSON);
        ServiceResponse<IndexSalesDTO> indexSales = this.indexSalesApiService.getIndexSales(enterpriseId, list, onLine,
                StringUtils.isNoneBlank(mbrAreaId) ? Long.valueOf(mbrAreaId) : null, dateTypeQo.getType(), dateTypeQo.getDate(), dataType);
        return RestResponse.success(EntityUtil.changeEntityByJSON(IndexSalesVo.class, indexSales.getResult()));
    }

    @RequestMapping("index-member")
    public RestResponse indexMember(Integer userId, Integer enterpriseId, String searchJSON,
                                   DateTypeQo dateTypeQo, String mbrAreaId){
        List<Integer> list = this.storeSearchUtils.storeSearch(userId, enterpriseId, searchJSON);
        List<String> onLine = this.storeSearchUtils.onLineStoreSearch(userId, enterpriseId, searchJSON);
        List<Long> mbrAreaIdList = this.dataAuthUtils.getMbrAreaId(userId, enterpriseId);
        ServiceResponse<IndexMemberDTO> indexMember = this.indexSalesApiService.getIndexMember(enterpriseId, list, onLine,
                StringUtils.isNoneBlank(mbrAreaId) ? Long.valueOf(mbrAreaId) : null,
                mbrAreaIdList, dateTypeQo.getType(), dateTypeQo.getDate());
        return RestResponse.success(indexMember.getResult());
    }

    @RequestMapping("index-consume")
    public RestResponse indexConsume(Integer userId, Integer enterpriseId, String searchJSON,
                                     DateTypeQo dateTypeQo, String mbrAreaId){
        List<Integer> list = this.storeSearchUtils.storeSearch(userId, enterpriseId, searchJSON);
        List<String> onLine = this.storeSearchUtils.onLineStoreSearch(userId, enterpriseId, searchJSON);
        List<Long> mbrAreaIdList = this.dataAuthUtils.getMbrAreaId(userId, enterpriseId);
        ServiceResponse<IndexMemberOrderCntDTO> response1 = this.indexSalesApiService.getIndexMemberOrderCnt(enterpriseId, list, onLine,
                StringUtils.isNoneBlank(mbrAreaId) ? Long.valueOf(mbrAreaId) : null,
                mbrAreaIdList, dateTypeQo.getType(), dateTypeQo.getDate(), 1);
        ServiceResponse<IndexMemberOrderCntDTO> response2 = this.indexSalesApiService.getIndexMemberOrderCnt(enterpriseId, list, onLine,
                StringUtils.isNoneBlank(mbrAreaId) ? Long.valueOf(mbrAreaId) : null,
                mbrAreaIdList, dateTypeQo.getType(), dateTypeQo.getDate(), 2);
        ServiceResponse<IndexMemberOldOrderCnt> oldOrderCnt = this.indexSalesApiService.getIndexMemberOldOrderCnt(enterpriseId, list, onLine,
                StringUtils.isNoneBlank(mbrAreaId) ? Long.valueOf(mbrAreaId) : null, mbrAreaIdList,
                dateTypeQo.getType(), dateTypeQo.getDate());
        ServiceResponse<IndexMemberBirthCntDTO> birthOrderCnt = this.indexSalesApiService.getIndexMemberBirthOrderCnt(enterpriseId, list, onLine,
                StringUtils.isNoneBlank(mbrAreaId) ? Long.valueOf(mbrAreaId) : null,
                mbrAreaIdList, dateTypeQo.getType(), dateTypeQo.getDate());
        log.info("response1:{}", JSON.toJSONString(response1));
        log.info("response2:{}", JSON.toJSONString(response2));
        log.info("oldOrderCnt:{}", JSON.toJSONString(oldOrderCnt));
        log.info("birthOrderCnt:{}", JSON.toJSONString(birthOrderCnt));
        IndexConsume consume = new IndexConsume();
        if(response1.isSuccess() && response1.getResult() != null && response2.getResult() != null){
            IndexMemberOrderCntDTO indexMemberOrderCntDTO1 = response1.getResult();
            IndexMemberOrderCntDTO indexMemberOrderCntDTO2 = response2.getResult();
            consume.setMemberRate(DataFormatUtils.rate(indexMemberOrderCntDTO1.getOrderCnt(), indexMemberOrderCntDTO2.getOrderCnt()));
            String divide = DataFormatUtils.divide(DataFormatUtils.divideDouble(indexMemberOrderCntDTO1.getOrderCnt(), indexMemberOrderCntDTO1.getOrderCntHb()),
                    DataFormatUtils.divideDouble(indexMemberOrderCntDTO2.getOrderCnt(), indexMemberOrderCntDTO2.getOrderCntHb()));
            consume.setMemberHb(divide);
        }
        if(oldOrderCnt.isSuccess() && oldOrderCnt.getResult() != null){
            IndexMemberOldOrderCnt indexMemberOldOrderCnt = oldOrderCnt.getResult();
            consume.setOldRate(DataFormatUtils.rate(indexMemberOldOrderCnt.getOldCnt(), indexMemberOldOrderCnt.getAllCnt()));
            consume.setOldHb(DataFormatUtils.divide(DataFormatUtils.divideDouble(indexMemberOldOrderCnt.getOldCnt(), indexMemberOldOrderCnt.getOldCntHb()),
                    DataFormatUtils.divideDouble(indexMemberOldOrderCnt.getAllCnt(), indexMemberOldOrderCnt.getAllCntHb())));
        }
        if(birthOrderCnt.isSuccess() && birthOrderCnt.getResult() != null){
            IndexMemberBirthCntDTO birthOrderCntResult = birthOrderCnt.getResult();
            consume.setBirthRate(DataFormatUtils.rate(birthOrderCntResult.getBirthCnt(), birthOrderCntResult.getAllCnt()));
            consume.setBirthHb(DataFormatUtils.divide(DataFormatUtils.divideDouble(birthOrderCntResult.getBirthCnt(), birthOrderCntResult.getBirthCntHb()),
                    DataFormatUtils.divideDouble(birthOrderCntResult.getAllCnt(), birthOrderCntResult.getBirthCntHb())));
        }
        return RestResponse.success(consume);
    }

    @RequestMapping("function-list")
    public RestResponse functionList(Integer userId){
        ServiceResponse<List<FunctionModuleDTO>> response = this.functionApiService.getFunctionByUserId(userId);
        List<FunctionModuleVo> list = new ArrayList<>();
        if(response.isSuccess() && CollectionUtils.isNotEmpty(response.getResult())){
            for(FunctionModuleDTO dto : response.getResult()){
                if(dto != null){
                    list.add(EntityUtil.changeEntityByJSON(FunctionModuleVo.class, dto));
                }
            }
        }
        return RestResponse.success(list);
    }

    @RequestMapping("get-level")
    public RestResponse getLevel(Integer userId, Integer enterpriseId, String searchJSON){
        LevelVo level = this.storeSearchUtils.getLevel(userId, enterpriseId, searchJSON);
        List<LevelNameVo> list = new ArrayList<>();
        LevelNameVo vo1 = new LevelNameVo(1, "第一层级", 1 >= level.getLevel() && 1 <= level.getMaxLevel() ? 1: 0);
        LevelNameVo vo2 = new LevelNameVo(2, "第二层级", 2 >= level.getLevel() && 2 <= level.getMaxLevel() ? 1: 0);
        LevelNameVo vo3 = new LevelNameVo(3, "第三层级", 3 >= level.getLevel() && 3 <= level.getMaxLevel() ? 1: 0);
        LevelNameVo vo4 = new LevelNameVo(4, "第四层级", 4 >= level.getLevel() && 4 <= level.getMaxLevel() ? 1: 0);
        LevelNameVo vo5 = new LevelNameVo(5, "第五层级", 5 >= level.getLevel() && 5 <= level.getMaxLevel() ? 1: 0);
        LevelNameVo vo6 = new LevelNameVo(6, "第六层级", 6 >= level.getLevel() && 6 <= level.getMaxLevel() ? 1: 0);
        list.add(vo1);
        list.add(vo2);
        list.add(vo3);
        list.add(vo4);
        list.add(vo5);
        list.add(vo6);
        return RestResponse.success(list);
    }

}
