package com.gic.cloud.web.utils;

import java.text.DecimalFormat;

/**
 * 数据处理
 * @ClassName: DataFormatUtils 
 * @Description:  
 * @author guojuxing 
 * @date 2020/7/28 11:09 AM 
 */
public class DataFormatUtils {

    /**
     * 如果大于十万，则以万为单位，否则就是元作为单位
     * @param data
     * @return
     */
    public static String toTenThousand(Double data) {
        if (data == null) {
            return "--";
        }
        if (data >= 100000) {
            return data / 10000 + "万";
        }
        return data + "";
    }

    /**
     * 数字每三位分割
     * @param data
     * @return
     */
    public static String splitData(Integer data) {
        DecimalFormat df = new DecimalFormat("###,###");
        if (data == null) {
            return "--";
        }
        return df.format(data);
    }

    /**
     * 相除
     * 数字每三位分割 并且保留2位小数
     * @param a
     * @param b
     * @return
     */
    public static String splitData(Double a, Integer b) {
        DecimalFormat df = new DecimalFormat("###,###.##");
        if (b == null || b == 0) {
            return "--";
        }
        return df.format(a / b);
    }

    /**
     * 相除
     * 数字每三位分割 并且保留2位小数
     * @param a
     * @param b
     * @return
     */
    public static String splitData(Double a, Double b) {
        DecimalFormat df = new DecimalFormat("###,###.##");
        if (b == null || b == 0) {
            return "--";
        }
        return df.format(a / b);
    }

    /**
     * 相除
     * 数字每三位分割 并且保留2位小数
     * @param a
     * @param b
     * @return
     */
    public static String splitData(Double a, Long b) {
        DecimalFormat df = new DecimalFormat("###,###.##");
        if (b == null || b == 0) {
            return "--";
        }
        return df.format(a / b);
    }

    /**
     * 相除
     * 数字每三位分割 并且保留2位小数
     * @param a
     * @param b
     * @return
     */
    public static String splitData(Long a, Long b) {
        DecimalFormat df = new DecimalFormat("###,###.##");
        if (b == null || b == 0) {
            return "--";
        }
        return df.format(a / b);
    }

    /**
     * 相除
     * 数字每三位分割 并且保留2位小数
     * @param a
     * @param b
     * @return
     */
    public static String splitData(Integer a, Integer b) {
        DecimalFormat df = new DecimalFormat("###,###.##");
        if (b == null || b == 0) {
            return "--";
        }
        return df.format(1.0 * a / b);
    }

    /**
     * +/-（a-b）/|b|*100%
     * @param a
     * @param b
     * @return
     */
    public static String divide(Double a, Double b) {
        if (b == null || b == 0) {
            return "--";
        }
        DecimalFormat df = new DecimalFormat("0.00");
        String sign = "";
        if ((a - b) >= 0) {
            sign = "+";
        }
        if (b < 0) {
            return sign + df.format((a - b) / (-1 * b) * 100) + "%";
        }
        return sign + df.format((a - b) / b * 100) + "%";
    }

    /**
     * +/-（a-b）/|b|*100%
     * @param a
     * @param b
     * @return
     */
    public static String divide(Double a, Integer b) {
        if (b == null || b == 0) {
            return "--";
        }
        DecimalFormat df = new DecimalFormat("0.00");
        String sign = "";
        if ((a - b) >= 0) {
            sign = "+";
        }
        if (b < 0) {
            return sign + df.format((a - b) / (-1 * b) * 100) + "%";
        }
        return sign + df.format((a - b) / b * 100) + "%";
    }

    /**
     * （a-b）/|b|*100%
     * @param a
     * @param b
     * @return
     */
    public static String divide(String a, String b) {
        Double a1 = Double.parseDouble(a);
        Double b1 = Double.parseDouble(b);
        if (b1 == null || b1 == 0) {
            return "--";
        }
        DecimalFormat df = new DecimalFormat("0.00");
        if (b1 < 0) {
            return df.format((a1 - b1) / (-1 * b1) * 100) + "%";
        }
        return df.format((a1 - b1) / b1 * 100) + "%";
    }

    /**
     * +/-（a-b）/|b|*100%
     * @param a
     * @param b
     * @return
     */
    public static String divide(Integer a, Integer b) {
        if (b == null || b == 0) {
            return "--";
        }
        DecimalFormat df = new DecimalFormat("0.00");
        String sign = "";
        if ((a - b) >= 0) {
            sign = "+";
        }
        if (b < 0) {
            return sign + df.format(1.0 * (a - b) / (-1 * b) * 100) + "%";
        }
        return sign + df.format(1.0 * (a - b) / b * 100) + "%";
    }

    /**
     * +/-（a-b）/|b|*100%
     * @param a
     * @param b
     * @return
     */
    public static Double divideDouble(Integer a, Integer b) {
        if (b == null || b == 0) {
            return 0d;
        }
        if (b < 0) {
            return 1.0 * (a - b) / (-1 * b) * 100;
        }
        return 1.0 * (a - b) / b * 100;
    }

    /**
     * 保留2位小数
     * @param data
     * @return
     */
    public static String twoFormat(Double data) {
        if (data == null || data == 0) {
            return "--";
        }
        DecimalFormat df = new DecimalFormat("0.00");
        return df.format(data);
    }

    /**
     * 占比
     * @param a
     * @param b
     * @return
     */
    public static String rate(Long a, Long b) {
        if (b == null || b == 0) {
            return "--";
        }
        return twoFormat(a * 1.0 / b * 100) + "%";
    }

    public static String rate(Double a, Double b) {
        if (b == null || b == 0) {
            return "--";
        }
        return twoFormat(a / b * 100) + "%";
    }

    public static String rate(Integer a, Integer b) {
        if (b == null || b == 0) {
            return "--";
        }
        return twoFormat(Double.valueOf(a) / Double.valueOf(b) * 100) + "%";
    }


}
